@@ -11,12 +11,10 @@ from typing import (
     Generic,
     Literal,
     TypeVar,
-    Union,
     cast,
 )
 
 import pystac
-from pystac.extensions import item_assets
 from pystac.extensions.base import (
     ExtensionManagementMixin,
     PropertiesExtension,
@@ -27,7 +25,9 @@ from pystac.extensions.raster import RasterBand
 from pystac.serialization.identify import STACJSONDescription, STACVersionID
 from pystac.utils import get_required, map_opt
 
-T = TypeVar("T", pystac.Item, pystac.Asset, item_assets.AssetDefinition, RasterBand)
+#: Generalized version of :class:`~pystac.Item`, :class:`~pystac.Asset`,
+#: :class:`~pystac.ItemAssetDefinition` or :class:`~pystac.extensions.raster.RasterBand`
+T = TypeVar("T", pystac.Item, pystac.Asset, pystac.ItemAssetDefinition, RasterBand)
 
 SCHEMA_URI_PATTERN: str = (
     "https://stac-extensions.github.io/classification/v{version}/schema.json"
@@ -487,12 +487,12 @@ class Bitfield:
 class ClassificationExtension(
     Generic[T],
     PropertiesExtension,
-    ExtensionManagementMixin[Union[pystac.Item, pystac.Collection]],
+    ExtensionManagementMixin[pystac.Item | pystac.Collection],
 ):
     """An abstract class that can be used to extend the properties of
     :class:`~pystac.Item`, :class:`~pystac.Asset`,
-    :class:`~pystac.extension.raster.RasterBand`, or
-    :class:`~pystac.extension.item_assets.AssetDefinition` with properties from the
+    :class:`~pystac.extensions.raster.RasterBand`, or
+    :class:`~pystac.ItemAssetDefinition` with properties from the
     :stac-ext:`Classification Extension <classification>`.  This class is generic
     over the type of STAC object being extended.
 
@@ -510,13 +510,13 @@ class ClassificationExtension(
         classes: list[Classification] | None = None,
         bitfields: list[Bitfield] | None = None,
     ) -> None:
-        """Applies the classifiation extension fields to the extended object.
+        """Applies the classification extension fields to the extended object.
 
         Note: one may set either the classes or bitfields objects, but not both.
 
         Args:
             classes: a list of
-                :class:`~pystac.extension.classification.Classification` objects
+                :class:`~pystac.extensions.classification.Classification` objects
                 describing the various classes in the classification
         """
         assert (
@@ -525,8 +525,10 @@ class ClassificationExtension(
             or bitfields is None
             and classes is not None
         ), "Must set exactly one of `classes` or `bitfields`"
-        self.classes = classes
-        self.bitfields = bitfields
+        if classes:
+            self.classes = classes
+        if bitfields:
+            self.bitfields = bitfields
 
     @property
     def classes(self) -> list[Classification] | None:
@@ -600,8 +602,8 @@ class ClassificationExtension(
 
         This extension can be applied to instances of :class:`~pystac.Item`,
         :class:`~pystac.Asset`,
-        :class:`~pystac.extensions.item_assets.AssetDefinition`, or
-        :class:`~pystac.extension.raster.RasterBand`.
+        :class:`~pystac.ItemAssetDefinition`, or
+        :class:`~pystac.extensions.raster.RasterBand`.
 
         Raises:
             pystac.ExtensionTypeError : If an invalid object type is passed
@@ -612,7 +614,7 @@ class ClassificationExtension(
         elif isinstance(obj, pystac.Asset):
             cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(ClassificationExtension[T], AssetClassificationExtension(obj))
-        elif isinstance(obj, item_assets.AssetDefinition):
+        elif isinstance(obj, pystac.ItemAssetDefinition):
             cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(
                 ClassificationExtension[T], ItemAssetsClassificationExtension(obj)
@@ -663,17 +665,19 @@ class AssetClassificationExtension(ClassificationExtension[pystac.Asset]):
 
 
 class ItemAssetsClassificationExtension(
-    ClassificationExtension[item_assets.AssetDefinition]
+    ClassificationExtension[pystac.ItemAssetDefinition]
 ):
     properties: dict[str, Any]
-    asset_defn: item_assets.AssetDefinition
+    asset_defn: pystac.ItemAssetDefinition
 
-    def __init__(self, item_asset: item_assets.AssetDefinition):
+    def __init__(self, item_asset: pystac.ItemAssetDefinition):
         self.asset_defn = item_asset
         self.properties = item_asset.properties
 
     def __repr__(self) -> str:
-        return f"<ItemAssetsClassificationExtension AssetDefinition={self.asset_defn}"
+        return (
+            f"<ItemAssetsClassificationExtension ItemAssetDefinition={self.asset_defn}"
+        )
 
 
 class RasterBandClassificationExtension(ClassificationExtension[RasterBand]):
