@@ -5,7 +5,7 @@ from __future__ import annotations
 import re
 import warnings
 from re import Pattern
-from typing import Any, Literal, Union
+from typing import Any, Literal
 
 import pystac
 from pystac.extensions.base import ExtensionManagementMixin, PropertiesExtension
@@ -37,14 +37,16 @@ def validated_code(v: str) -> str:
 
 class GridExtension(
     PropertiesExtension,
-    ExtensionManagementMixin[Union[pystac.Item, pystac.Collection]],
+    ExtensionManagementMixin[pystac.Item | pystac.Collection],
 ):
-    """A concrete implementation of :class:`GridExtension` on an :class:`~pystac.Item`
+    """A concrete implementation of :class:`~pystac.extensions.grid.GridExtension`
+    on an :class:`~pystac.Item`
     that extends the properties of the Item to include properties defined in the
     :stac-ext:`Grid Extension <grid>`.
 
     This class should generally not be instantiated directly. Instead, call
-    :meth:`GridExtension.ext` on an :class:`~pystac.Item` to extend it.
+    :meth:`~pystac.extensions.grid.GridExtension.ext` on an :class:`~pystac.Item`
+    to extend it.
 
     .. code-block:: python
 
