@@ -2,7 +2,14 @@
 
 from __future__ import annotations
 
-from typing import Any, Dict, Generic, Iterable, List, Optional, TypeVar, Union, cast
+from collections.abc import Iterable
+from typing import (
+    Any,
+    Generic,
+    Literal,
+    TypeVar,
+    cast,
+)
 
 import pystac
 from pystac.extensions.base import (
@@ -14,7 +21,9 @@ from pystac.extensions.hooks import ExtensionHooks
 from pystac.summaries import RangeSummary
 from pystac.utils import StringEnum, get_required, map_opt
 
-T = TypeVar("T", pystac.Item, pystac.Asset)
+#: Generalized version of :class:`~pystac.Item`, :class:`~pystac.Asset`,
+#: or :class:`~pystac.ItemAssetDefinition`
+T = TypeVar("T", pystac.Item, pystac.Asset, pystac.ItemAssetDefinition)
 
 SCHEMA_URI: str = "https://stac-extensions.github.io/pointcloud/v1.0.0/schema.json"
 PREFIX: str = "pc:"
@@ -54,9 +63,9 @@ class Schema:
     properties.
     """
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
-    def __init__(self, properties: Dict[str, Any]) -> None:
+    def __init__(self, properties: dict[str, Any]) -> None:
         self.properties = properties
 
     def apply(self, name: str, size: int, type: SchemaType) -> None:
@@ -94,7 +103,7 @@ class Schema:
     @size.setter
     def size(self, v: int) -> None:
         if not isinstance(v, int):
-            raise pystac.STACError("size must be an int! Invalid input: {}".format(v))
+            raise pystac.STACError(f"size must be an int! Invalid input: {v}")
 
         self.properties["size"] = v
 
@@ -124,8 +133,8 @@ class Schema:
             self.properties.get("type"),
         )
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Returns a JSON-like dictionary representing this ``Schema``."""
+    def to_dict(self) -> dict[str, Any]:
+        """Returns this schema as a dictionary."""
         return self.properties
 
 
@@ -135,21 +144,21 @@ class Statistic:
     Use :meth:`Statistic.create` to create a new instance of
     ``Statistic`` from property values."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
-    def __init__(self, properties: Dict[str, Any]) -> None:
+    def __init__(self, properties: dict[str, Any]) -> None:
         self.properties = properties
 
     def apply(
         self,
         name: str,
-        position: Optional[int] = None,
-        average: Optional[float] = None,
-        count: Optional[int] = None,
-        maximum: Optional[float] = None,
-        minimum: Optional[float] = None,
-        stddev: Optional[float] = None,
-        variance: Optional[float] = None,
+        position: int | None = None,
+        average: float | None = None,
+        count: int | None = None,
+        maximum: float | None = None,
+        minimum: float | None = None,
+        stddev: float | None = None,
+        variance: float | None = None,
     ) -> None:
         """Sets the properties for this Statistic.
 
@@ -176,13 +185,13 @@ class Statistic:
     def create(
         cls,
         name: str,
-        position: Optional[int] = None,
-        average: Optional[float] = None,
-        count: Optional[int] = None,
-        maximum: Optional[float] = None,
-        minimum: Optional[float] = None,
-        stddev: Optional[float] = None,
-        variance: Optional[float] = None,
+        position: int | None = None,
+        average: float | None = None,
+        count: int | None = None,
+        maximum: float | None = None,
+        minimum: float | None = None,
+        stddev: float | None = None,
+        variance: float | None = None,
     ) -> Statistic:
         """Creates a new Statistic class.
 
@@ -222,94 +231,94 @@ class Statistic:
             self.properties.pop("name", None)
 
     @property
-    def position(self) -> Optional[int]:
+    def position(self) -> int | None:
         """Gets or sets the position property."""
         return self.properties.get("position")
 
     @position.setter
-    def position(self, v: Optional[int]) -> None:
+    def position(self, v: int | None) -> None:
         if v is not None:
             self.properties["position"] = v
         else:
             self.properties.pop("position", None)
 
     @property
-    def average(self) -> Optional[float]:
+    def average(self) -> float | None:
         """Gets or sets the average property."""
         return self.properties.get("average")
 
     @average.setter
-    def average(self, v: Optional[float]) -> None:
+    def average(self, v: float | None) -> None:
         if v is not None:
             self.properties["average"] = v
         else:
             self.properties.pop("average", None)
 
     @property
-    def count(self) -> Optional[int]:
+    def count(self) -> int | None:
         """Gets or sets the count property."""
         return self.properties.get("count")
 
     @count.setter
-    def count(self, v: Optional[int]) -> None:
+    def count(self, v: int | None) -> None:
         if v is not None:
             self.properties["count"] = v
         else:
             self.properties.pop("count", None)
 
     @property
-    def maximum(self) -> Optional[float]:
+    def maximum(self) -> float | None:
         """Gets or sets the maximum property."""
         return self.properties.get("maximum")
 
     @maximum.setter
-    def maximum(self, v: Optional[float]) -> None:
+    def maximum(self, v: float | None) -> None:
         if v is not None:
             self.properties["maximum"] = v
         else:
             self.properties.pop("maximum", None)
 
     @property
-    def minimum(self) -> Optional[float]:
+    def minimum(self) -> float | None:
         """Gets or sets the minimum property."""
         return self.properties.get("minimum")
 
     @minimum.setter
-    def minimum(self, v: Optional[float]) -> None:
+    def minimum(self, v: float | None) -> None:
         if v is not None:
             self.properties["minimum"] = v
         else:
             self.properties.pop("minimum", None)
 
     @property
-    def stddev(self) -> Optional[float]:
+    def stddev(self) -> float | None:
         """Gets or sets the stddev property."""
         return self.properties.get("stddev")
 
     @stddev.setter
-    def stddev(self, v: Optional[float]) -> None:
+    def stddev(self, v: float | None) -> None:
         if v is not None:
             self.properties["stddev"] = v
         else:
             self.properties.pop("stddev", None)
 
     @property
-    def variance(self) -> Optional[float]:
+    def variance(self) -> float | None:
         """Gets or sets the variance property."""
         return self.properties.get("variance")
 
     @variance.setter
-    def variance(self, v: Optional[float]) -> None:
+    def variance(self, v: float | None) -> None:
         if v is not None:
             self.properties["variance"] = v
         else:
             self.properties.pop("variance", None)
 
     def __repr__(self) -> str:
-        return "<Statistic statistics={}>".format(str(self.properties))
+        return f"<Statistic statistics={str(self.properties)}>"
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Returns a JSON-like dictionary representing this ``Statistic``."""
+    def to_dict(self) -> dict[str, Any]:
+        """Returns this statistic as a dictionary."""
         return self.properties
 
     def __eq__(self, o: object) -> bool:
@@ -321,7 +330,7 @@ class Statistic:
 class PointcloudExtension(
     Generic[T],
     PropertiesExtension,
-    ExtensionManagementMixin[Union[pystac.Item, pystac.Collection]],
+    ExtensionManagementMixin[pystac.Item | pystac.Collection],
 ):
     """An abstract class that can be used to extend the properties of an
     :class:`~pystac.Item` or :class:`~pystac.Asset` with properties from the
@@ -338,14 +347,16 @@ class PointcloudExtension(
        >>> pc_ext = PointcloudExtension.ext(item)
     """
 
+    name: Literal["pc"] = "pc"
+
     def apply(
         self,
         count: int,
-        type: Union[PhenomenologyType, str],
+        type: PhenomenologyType | str,
         encoding: str,
-        schemas: List[Schema],
-        density: Optional[float] = None,
-        statistics: Optional[List[Statistic]] = None,
+        schemas: list[Schema],
+        density: float | None = None,
+        statistics: list[Statistic] | None = None,
     ) -> None:
         """Applies Pointcloud extension properties to the extended Item.
 
@@ -378,12 +389,12 @@ class PointcloudExtension(
         self._set_property(COUNT_PROP, v, pop_if_none=False)
 
     @property
-    def type(self) -> Union[PhenomenologyType, str]:
+    def type(self) -> PhenomenologyType | str:
         """Gets or sets the phenomenology type for the point cloud."""
         return get_required(self._get_property(TYPE_PROP, str), self, TYPE_PROP)
 
     @type.setter
-    def type(self, v: Union[PhenomenologyType, str]) -> None:
+    def type(self, v: PhenomenologyType | str) -> None:
         self._set_property(TYPE_PROP, v, pop_if_none=False)
 
     @property
@@ -396,38 +407,38 @@ class PointcloudExtension(
         self._set_property(ENCODING_PROP, v, pop_if_none=False)
 
     @property
-    def schemas(self) -> List[Schema]:
+    def schemas(self) -> list[Schema]:
         """Gets or sets the list of :class:`Schema` instances defining
         dimensions and types for the data.
         """
         result = get_required(
-            self._get_property(SCHEMAS_PROP, List[Dict[str, Any]]), self, SCHEMAS_PROP
+            self._get_property(SCHEMAS_PROP, list[dict[str, Any]]), self, SCHEMAS_PROP
         )
         return [Schema(s) for s in result]
 
     @schemas.setter
-    def schemas(self, v: List[Schema]) -> None:
+    def schemas(self, v: list[Schema]) -> None:
         self._set_property(SCHEMAS_PROP, [x.to_dict() for x in v], pop_if_none=False)
 
     @property
-    def density(self) -> Optional[float]:
+    def density(self) -> float | None:
         """Gets or sets the number of points per square unit area."""
         return self._get_property(DENSITY_PROP, float)
 
     @density.setter
-    def density(self, v: Optional[float]) -> None:
+    def density(self, v: float | None) -> None:
         self._set_property(DENSITY_PROP, v)
 
     @property
-    def statistics(self) -> Optional[List[Statistic]]:
+    def statistics(self) -> list[Statistic] | None:
         """Gets or sets the list of :class:`Statistic` instances describing
         the pre-channel statistics. Elements in this list map to elements in the
         :attr:`PointcloudExtension.schemas` list."""
-        result = self._get_property(STATISTICS_PROP, List[Dict[str, Any]])
+        result = self._get_property(STATISTICS_PROP, list[dict[str, Any]])
         return map_opt(lambda stats: [Statistic(s) for s in stats], result)
 
     @statistics.setter
-    def statistics(self, v: Optional[List[Statistic]]) -> None:
+    def statistics(self, v: list[Statistic] | None) -> None:
         set_value = map_opt(lambda stats: [s.to_dict() for s in stats], v)
         self._set_property(STATISTICS_PROP, set_value)
 
@@ -448,25 +459,26 @@ class PointcloudExtension(
             pystac.ExtensionTypeError : If an invalid object type is passed.
         """
         if isinstance(obj, pystac.Item):
-            cls.validate_has_extension(obj, add_if_missing)
+            cls.ensure_has_extension(obj, add_if_missing)
             return cast(PointcloudExtension[T], ItemPointcloudExtension(obj))
         elif isinstance(obj, pystac.Asset):
             if obj.owner is not None and not isinstance(obj.owner, pystac.Item):
                 raise pystac.ExtensionTypeError(
                     "Pointcloud extension does not apply to Collection Assets."
                 )
-            cls.validate_owner_has_extension(obj, add_if_missing)
+            cls.ensure_owner_has_extension(obj, add_if_missing)
             return cast(PointcloudExtension[T], AssetPointcloudExtension(obj))
+        elif isinstance(obj, pystac.ItemAssetDefinition):
+            cls.ensure_owner_has_extension(obj, add_if_missing)
+            return cast(PointcloudExtension[T], ItemAssetsPointcloudExtension(obj))
         else:
-            raise pystac.ExtensionTypeError(
-                f"Pointcloud extension does not apply to type '{type(obj).__name__}'"
-            )
+            raise pystac.ExtensionTypeError(cls._ext_error_message(obj))
 
     @classmethod
     def summaries(
         cls, obj: pystac.Collection, add_if_missing: bool = False
     ) -> SummariesPointcloudExtension:
-        cls.validate_has_extension(obj, add_if_missing)
+        cls.ensure_has_extension(obj, add_if_missing)
         return SummariesPointcloudExtension(obj)
 
 
@@ -480,14 +492,14 @@ class ItemPointcloudExtension(PointcloudExtension[pystac.Item]):
     """
 
     item: pystac.Item
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
 
     def __init__(self, item: pystac.Item):
         self.item = item
         self.properties = item.properties
 
     def __repr__(self) -> str:
-        return "<ItemPointcloudExtension Item id={}>".format(self.item.id)
+        return f"<ItemPointcloudExtension Item id={self.item.id}>"
 
 
 class AssetPointcloudExtension(PointcloudExtension[pystac.Asset]):
@@ -502,10 +514,10 @@ class AssetPointcloudExtension(PointcloudExtension[pystac.Asset]):
     asset_href: str
     """The ``href`` value of the :class:`~pystac.Asset` being extended."""
 
-    properties: Dict[str, Any]
+    properties: dict[str, Any]
     """The :class:`~pystac.Asset` fields, including extension properties."""
 
-    additional_read_properties: Optional[Iterable[Dict[str, Any]]] = None
+    additional_read_properties: Iterable[dict[str, Any]] | None = None
     """If present, this will be a list containing 1 dictionary representing the
     properties of the owning :class:`~pystac.Item`."""
 
@@ -522,53 +534,62 @@ class AssetPointcloudExtension(PointcloudExtension[pystac.Asset]):
         return f"<AssetPointcloudExtension Asset {self.repr_id}>"
 
 
+class ItemAssetsPointcloudExtension(PointcloudExtension[pystac.ItemAssetDefinition]):
+    properties: dict[str, Any]
+    asset_defn: pystac.ItemAssetDefinition
+
+    def __init__(self, item_asset: pystac.ItemAssetDefinition):
+        self.asset_defn = item_asset
+        self.properties = item_asset.properties
+
+
 class SummariesPointcloudExtension(SummariesExtension):
-    """A concrete implementation of :class:`~SummariesExtension` that extends
-    the ``summaries`` field of a :class:`~pystac.Collection` to include properties
-    defined in the :stac-ext:`Point Cloud Extension <pointcloud>`.
+    """A concrete implementation of :class:`~pystac.extensions.base.SummariesExtension`
+    that extends the ``summaries`` field of a :class:`~pystac.Collection` to include
+    properties defined in the :stac-ext:`Point Cloud Extension <pointcloud>`.
     """
 
     @property
-    def count(self) -> Optional[RangeSummary[int]]:
+    def count(self) -> RangeSummary[int] | None:
         return self.summaries.get_range(COUNT_PROP)
 
     @count.setter
-    def count(self, v: Optional[RangeSummary[int]]) -> None:
+    def count(self, v: RangeSummary[int] | None) -> None:
         self._set_summary(COUNT_PROP, v)
 
     @property
-    def type(self) -> Optional[List[Union[PhenomenologyType, str]]]:
+    def type(self) -> list[PhenomenologyType | str] | None:
         return self.summaries.get_list(TYPE_PROP)
 
     @type.setter
-    def type(self, v: Optional[List[Union[PhenomenologyType, str]]]) -> None:
+    def type(self, v: list[PhenomenologyType | str] | None) -> None:
         self._set_summary(TYPE_PROP, v)
 
     @property
-    def encoding(self) -> Optional[List[str]]:
+    def encoding(self) -> list[str] | None:
         return self.summaries.get_list(ENCODING_PROP)
 
     @encoding.setter
-    def encoding(self, v: Optional[List[str]]) -> None:
+    def encoding(self, v: list[str] | None) -> None:
         self._set_summary(ENCODING_PROP, v)
 
     @property
-    def density(self) -> Optional[RangeSummary[float]]:
+    def density(self) -> RangeSummary[float] | None:
         return self.summaries.get_range(DENSITY_PROP)
 
     @density.setter
-    def density(self, v: Optional[RangeSummary[float]]) -> None:
+    def density(self, v: RangeSummary[float] | None) -> None:
         self._set_summary(DENSITY_PROP, v)
 
     @property
-    def statistics(self) -> Optional[List[Statistic]]:
+    def statistics(self) -> list[Statistic] | None:
         return map_opt(
             lambda stats: [Statistic(d) for d in stats],
             self.summaries.get_list(STATISTICS_PROP),
         )
 
     @statistics.setter
-    def statistics(self, v: Optional[List[Statistic]]) -> None:
+    def statistics(self, v: list[Statistic] | None) -> None:
         self._set_summary(
             STATISTICS_PROP,
             map_opt(lambda stats: [s.to_dict() for s in stats], v),
