@@ -20,6 +20,7 @@ def _migrate_catalog(
     d: dict[str, Any], version: STACVersionID, info: STACJSONDescription
 ) -> None:
     d["type"] = pystac.STACObjectType.CATALOG
+    _migrate_license(d)
 
 
 def _migrate_collection_summaries(
@@ -38,25 +39,20 @@ def _migrate_collection(
     d: dict[str, Any], version: STACVersionID, info: STACJSONDescription
 ) -> None:
     d["type"] = pystac.STACObjectType.COLLECTION
+    _migrate_license(d)
     _migrate_collection_summaries(d, version, info)
 
 
 def _migrate_item(
     d: dict[str, Any], version: STACVersionID, info: STACJSONDescription
 ) -> None:
-    # No migrations necessary for supported STAC versions (>=0.8)
-    pass
+    _migrate_license(d["properties"])
 
 
-# Extensions
-def _migrate_item_assets(
-    d: dict[str, Any], version: STACVersionID, info: STACJSONDescription
-) -> set[str] | None:
-    if version < "1.0.0-beta.2":
-        if info.object_type == pystac.STACObjectType.COLLECTION:
-            if "assets" in d:
-                d["item_assets"] = d["assets"]
-                del d["assets"]
+def _migrate_license(d: dict[str, Any]) -> None:
+    if d.get("license") in ["various", "proprietary"]:
+        d["license"] = "other"
+
     return None
 
 
@@ -158,11 +154,6 @@ def _get_removed_extension_migrations() -> (
     }
 
 
-# TODO: Item Assets
-def _get_extension_renames() -> dict[str, str]:
-    return {"asset": "item-assets"}
-
-
 def migrate_to_latest(
     json_dict: dict[str, Any], info: STACJSONDescription
 ) -> dict[str, Any]:
@@ -171,7 +162,7 @@ def migrate_to_latest(
     Args:
         json_dict : The dict of STAC JSON to identify.
         info : The info from
-            :func:`~pystac.serialization.identify.identify_stac_object` that describes
+            :func:`~pystac.serialization.identify_stac_object` that describes
             the STAC object contained in the JSON dict.
 
     Returns:
