@@ -366,8 +366,9 @@ class EOMigrationTest(unittest.TestCase):
         item = Item.from_file(self.item_0_8_path)
 
         self.assertNotIn("eo:epsg", item.properties)
-        self.assertIn("proj:epsg", item.properties)
+        self.assertIn("proj:code", item.properties)
         self.assertIn(ProjectionExtension.get_schema_uri(), item.stac_extensions)
+        assert item.ext.proj.epsg == item_dict["properties"]["eo:epsg"]
 
 
 @pytest.fixture
@@ -438,7 +439,7 @@ def test_older_extension_version(ext_item: Item) -> None:
     stac_extensions.add(old)
     item_as_dict = ext_item.to_dict(include_self_link=False, transform_hrefs=False)
     item_as_dict["stac_extensions"] = list(stac_extensions)
-    item = Item.from_dict(item_as_dict)
+    item = Item.from_dict(item_as_dict, migrate=False)
     assert EOExtension.has_extension(item)
     assert old in item.stac_extensions
 
@@ -515,3 +516,18 @@ def test_required_property_missing(ext_item: pystac.Item) -> None:
     assert bands is not None
     with pytest.raises(RequiredPropertyMissing):
         bands[0].name
+
+
+def test_unnecessary_migrations_not_performed(ext_item: Item) -> None:
+    item_as_dict = ext_item.to_dict(include_self_link=False, transform_hrefs=False)
+    item_as_dict["stac_version"] = "1.0.0"
+    item_as_dict["properties"]["eo:bands"] = [{"name": "B1", "common_name": "coastal"}]
+
+    item = Item.from_dict(item_as_dict)
+
+    migrated_item = pystac.Item.from_dict(item_as_dict, migrate=True)
+
+    assert item.properties == migrated_item.properties
+    assert len(item.assets) == len(migrated_item.assets)
+    for key, value in item.assets.items():
+        assert value.to_dict() == migrated_item.assets[key].to_dict()
