@@ -10,6 +10,7 @@ import pytest
 
 import pystac
 from pystac import Collection, Item, Link
+from pystac.errors import STACError
 from pystac.link import HIERARCHICAL_LINKS
 from pystac.utils import make_posix_style
 from tests.utils.test_cases import ARBITRARY_EXTENT
@@ -98,6 +99,14 @@ class LinkTest(unittest.TestCase):
         link = pystac.Link("my rel", target=self.item)
         link.resolve_stac_object()
 
+    @pytest.mark.skipif(os.name == "nt", reason="Non-windows test")
+    def test_resolve_stac_object_throws_informative_error(self) -> None:
+        link = pystac.Link("root", target="/a/b/foo.json")
+        with pytest.raises(
+            STACError, match="HREF: '/a/b/foo.json' does not resolve to a STAC object"
+        ):
+            link.resolve_stac_object()
+
     def test_resolved_self_href(self) -> None:
         catalog = pystac.Catalog(id="test", description="test desc")
         with TemporaryDirectory() as temporary_directory:
@@ -346,3 +355,9 @@ def test_is_hierarchical(rel: str) -> None:
 )
 def test_is_not_hierarchical(rel: str) -> None:
     assert not Link(rel, "a-target").is_hierarchical()
+
+
+def test_item_link_type(item: Item) -> None:
+    # https://github.com/stac-utils/pystac/issues/1494
+    link = Link.item(item)
+    assert link.media_type == "application/geo+json"
